currencies = {
    "eur": {"name": "Euro", "id": "euro"},
    "cny": {"name": "Yuan chino", "id": "yuan"},
    "try": {"name": "Lira turca", "id": "lira"},
    "rub": {"name": "Rublo ruso", "id": "rublo"},
    "usd": {"name": "Dólar estadounidense", "id": "dolar"}
}

monitors = {'binance': 'Binance', 'dolartoday': 'DolarToday',
            'yadio': 'Yadio', 'airtm': 'Airtm', 'cambiosrya': 'Cambios R&A',
            'mkambio': 'Mkambio', 'bcv': 'BCV', 'promediovip': 'EnParaleloVzlaVip',
            'prom_epv': 'EnParalelovzla'}

monitors_exchange = ["dolar-em", "monitor_dolar_venezuela", "enparalelovzla", "monitor_dolar_vzla", "petro",
"bcv", "remesas_zoom", "italcambio","bancamiga","banco_de_venezuela","banco-exterior",
"banplus","bnc","banesco","bbva_provincial","mercantil","otras_instituciones",
"binance","airtm","reserve","syklo","yadio",
"dolartoday","mkambio" ,"cambios-r&a" ,"paypal" ,"zinli" ,
"skrill" ,"amazon_gift_card"]

time_units = {
    "semana": "weeks", "semanas": "weeks",
    "día": "days", "días": "days",
    "horas": "hours", "hora": "hours",
    "minutos": "minutes", "minuto": "minutes",
    "segundos": "seconds", "segundo": "seconds"
}